@@ -10,7 +10,7 @@ set.seed(1234)
 
 
 ###################################################
-### code chunk number 2: seriation.Rnw:930-936
+### code chunk number 2: seriation.Rnw:954-960
 ###################################################
 library("seriation")
 
@@ -21,14 +21,14 @@ d <- dist(x)
 
 
 ###################################################
-### code chunk number 3: seriation.Rnw:942-944
+### code chunk number 3: seriation.Rnw:966-968
 ###################################################
 o <- seriate(d)
 o
 
 
 ###################################################
-### code chunk number 4: seriation.Rnw:955-956
+### code chunk number 4: seriation.Rnw:979-980
 ###################################################
 head(get_order(o), 15)
 
@@ -36,17 +36,17 @@ head(get_order(o), 15)
 ###################################################
 ### code chunk number 5: pimage1
 ###################################################
-pimage(d, main = "Random", colorkey=TRUE)
+pimage(d, main = "Random")
 
 
 ###################################################
 ### code chunk number 6: pimage1-2
 ###################################################
-pimage(d, o, main = "Reordered", colorkey=TRUE)
+pimage(d, o, main = "Reordered")
 
 
 ###################################################
-### code chunk number 7: seriation.Rnw:981-982
+### code chunk number 7: seriation.Rnw:1005-1006
 ###################################################
 cbind(random = criterion(d), reordered = criterion(d, o))
 
@@ -54,29 +54,25 @@ cbind(random = criterion(d), reordered = criterion(d, o))
 ###################################################
 ### code chunk number 8: pimage2
 ###################################################
-library("colorspace")
-pimage(scale(x), main = "Random", colorkey=TRUE, 
-    col=diverge_hcl(100), range=c(-3.5,3.5))
+pimage(scale(x), main = "Random")
 
 
 ###################################################
 ### code chunk number 9: pimage2-2
 ###################################################
-o_2mode <- c(o, ser_permutation(seq_len(ncol(x))))
-#o_2mode
-pimage(scale(x), o_2mode, main = "Reordered", 
-    colorkey=TRUE, col=diverge_hcl(100), range=c(-3.5,3.5))
+o_2mode <- c(o, NA)
+pimage(scale(x), o_2mode, main = "Reordered")
 
 
 ###################################################
-### code chunk number 10: seriation.Rnw:1034-1036
+### code chunk number 10: seriation.Rnw:1055-1057
 ###################################################
-methods <- c("TSP","Chen", "ARSA", "HC", "GW", "OLO")
-o <- sapply(methods, FUN = function(m) seriate(d, m), simplify = FALSE)
+methods <- c("TSP","R2E", "ARSA", "HC", "GW", "OLO")
+o <- sapply(methods, FUN = function(m) seriate(d, m))
 
 
 ###################################################
-### code chunk number 11: seriation.Rnw:1039-1041
+### code chunk number 11: seriation.Rnw:1060-1062
 ###################################################
 timing <- sapply(methods, FUN = function(m) system.time(seriate(d, m)), 
     simplify = FALSE)
@@ -85,15 +81,17 @@ timing <- sapply(methods, FUN = function(m) system.time(seriate(d, m)),
 ###################################################
 ### code chunk number 12: pimage3-pre (eval = FALSE)
 ###################################################
-## tmp <- lapply(o, FUN = function(x) pimage(d, x, main = get_method(x[[1]])))
+## o <- seriation_align(o)
+## for(s in o) pimage(d, s, main = get_method(s), key = FALSE)
 
 
 ###################################################
 ### code chunk number 13: pimage3
 ###################################################
+o <- seriation_align(o)
 for(i in 1:length(o)) {
     pdf(file=paste("seriation-pimage_comp_", i , ".pdf", sep=""))
-    pimage(d, o[[i]], main = get_method(o[[i]][[1]]))
+    pimage(d, o[[i]], main = get_method(o[[i]]), key = FALSE)
     dev.off()
 }
 
@@ -102,21 +100,21 @@ for(i in 1:length(o)) {
 ###################################################
 ### code chunk number 14: pimage3_dend (eval = FALSE)
 ###################################################
-## plot(o[["HC"]][[1]], labels = FALSE, main = "Dendrogram HC")
-## plot(o[["GW"]][[1]], labels = FALSE, main = "Dendrogram GW")
+## plot(o[["HC"]], labels = FALSE, main = "Dendrogram HC")
+## plot(o[["GW"]], labels = FALSE, main = "Dendrogram GW")
 
 
 ###################################################
-### code chunk number 15: seriation.Rnw:1135-1147
+### code chunk number 15: seriation.Rnw:1159-1171
 ###################################################
 def.par <- par(no.readonly = TRUE)
 pdf(file="seriation-pimage3_dendrogram.pdf", width=9, height=4) 
 layout(t(1:2))
-plot(o[["HC"]][[1]], labels = FALSE, main = "Dendrogram HC")
+plot(o[["HC"]], labels = FALSE, main = "Dendrogram HC")
 symbols(74.7,.5, rect = matrix(c(4, 3), ncol=2), add= TRUE, 
     inches = FALSE, lwd =2)
 
-plot(o[["GW"]][[1]], labels = FALSE, main = "Dendrogram GW")
+plot(o[["GW"]], labels = FALSE, main = "Dendrogram GW")
 symbols(98.7,.5, rect = matrix(c(4, 3), ncol=2), add= TRUE, 
     inches = FALSE, lwd =2)
 par(def.par)
@@ -124,7 +122,7 @@ tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 16: seriation.Rnw:1165-1167
+### code chunk number 16: seriation.Rnw:1189-1191
 ###################################################
 crit <- sapply(o, FUN = function(x) criterion(d, x))
 t(crit)
@@ -142,42 +140,42 @@ par(def.par)
 
 
 ###################################################
-### code chunk number 18: seriation.Rnw:1209-1211
+### code chunk number 18: seriation.Rnw:1233-1235
 ###################################################
-show_seriation_methods("dist")
-show_seriation_methods("matrix")
+show_seriation_methods("dist")[1:3]
+show_seriation_methods("matrix")[1:3]
 
 
 ###################################################
-### code chunk number 19: seriation.Rnw:1218-1219
+### code chunk number 19: seriation.Rnw:1242-1243
 ###################################################
 list_seriation_methods("matrix")
 
 
 ###################################################
-### code chunk number 20: seriation.Rnw:1235-1238
+### code chunk number 20: seriation.Rnw:1259-1262
 ###################################################
-seriation_method_identity <- function(x, control) {
-           lapply(dim(x), seq)
+seriation_method_reverse <- function(x, control = NULL) {
+           lapply(dim(x), function(n) rev(seq(n)))
 }
 
 
 ###################################################
-### code chunk number 21: seriation.Rnw:1246-1251
+### code chunk number 21: seriation.Rnw:1270-1275
 ###################################################
-set_seriation_method("matrix", "identity", seriation_method_identity,
-    "Identity order")
+set_seriation_method("matrix", "Reverse", seriation_method_reverse,
+    "Reverse identity order")
 
-set_seriation_method("array", "identity", seriation_method_identity,
-    "Identity order")
+set_seriation_method("array", "Reverse", seriation_method_reverse,
+    "Reverse identity order")
 
 
 ###################################################
-### code chunk number 22: seriation.Rnw:1256-1263
+### code chunk number 22: seriation.Rnw:1280-1287
 ###################################################
 show_seriation_methods("matrix")
 
-o <- seriate(matrix(1, ncol=3, nrow=4), "identity")
+o <- seriate(matrix(1, ncol=3, nrow=4), "reverse")
 o
 
 get_order(o, 1)
@@ -185,50 +183,50 @@ get_order(o, 2)
 
 
 ###################################################
-### code chunk number 23: seriation.Rnw:1297-1298
+### code chunk number 23: seriation.Rnw:1321-1322
 ###################################################
 x <- scale(x, center = FALSE)
 
 
 ###################################################
-### code chunk number 24: seriation.Rnw:1304-1305 (eval = FALSE)
+### code chunk number 24: seriation.Rnw:1329-1330 (eval = FALSE)
 ###################################################
-## hmap(x)
+## hmap(x, margin =c(7, 4), cexCol=1, labRow = FALSE)
 
 
 ###################################################
-### code chunk number 25: seriation.Rnw:1315-1316 (eval = FALSE)
+### code chunk number 25: seriation.Rnw:1340-1341 (eval = FALSE)
 ###################################################
-## hmap(x, hclustfun = NULL)
+## hmap(x, method = "MDS")
 
 
 ###################################################
-### code chunk number 26: seriation.Rnw:1326-1331
+### code chunk number 26: seriation.Rnw:1351-1356
 ###################################################
 #bitmap(file = "seriation-heatmap1.png", type = "pnggray", 
 #    height = 6, width = 6, res = 300, pointsize=14)
 pdf(file = "seriation-heatmap1.pdf")
-hmap(x, cexCol=1, labRow = "", margin =c(7,7))
+hmap(x, margin = c(7, 4), labRow = FALSE, cexCol=1)
 tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 27: seriation.Rnw:1333-1336
+### code chunk number 27: seriation.Rnw:1358-1361
 ###################################################
 pdf(file = "seriation-heatmap2.pdf")
-hmap(x, hclustfun = NULL)
+hmap(x, method="MDS")
 tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 28: seriation.Rnw:1402-1404
+### code chunk number 28: seriation.Rnw:1427-1429
 ###################################################
 data("Irish")
 orig_matrix <- apply(Irish[,-6], 2, rank)
 
 
 ###################################################
-### code chunk number 29: seriation.Rnw:1414-1419
+### code chunk number 29: seriation.Rnw:1439-1444
 ###################################################
 o <- c(
     seriate(dist(orig_matrix, "minkowski", p = 1), method ="TSP"),
@@ -238,7 +236,7 @@ o
 
 
 ###################################################
-### code chunk number 30: seriation.Rnw:1424-1426 (eval = FALSE)
+### code chunk number 30: seriation.Rnw:1449-1451 (eval = FALSE)
 ###################################################
 ## bertinplot(orig_matrix)
 ## bertinplot(orig_matrix, o)
@@ -266,7 +264,7 @@ bertinplot(Townships, options = list(panel=panel.squares, spacing = 0,
 
 
 ###################################################
-### code chunk number 34: seriation.Rnw:1504-1506
+### code chunk number 34: seriation.Rnw:1529-1531
 ###################################################
 ## to get consistent results
 set.seed(5)
@@ -281,13 +279,13 @@ bertinplot(Townships, o, options = list(panel=panel.squares, spacing = 0,
 
 
 ###################################################
-### code chunk number 36: seriation.Rnw:1546-1547
+### code chunk number 36: seriation.Rnw:1571-1572
 ###################################################
 rbind(original = criterion(Townships), reordered = criterion(Townships, o))
 
 
 ###################################################
-### code chunk number 37: seriation.Rnw:1614-1617
+### code chunk number 37: seriation.Rnw:1639-1642
 ###################################################
 data("iris")
 iris <- iris[sample(seq_len(nrow(iris))),]
@@ -309,7 +307,7 @@ d <- dist(as.matrix(iris[-5]), method = "euclidean")
 
 
 ###################################################
-### code chunk number 40: seriation.Rnw:1639-1645
+### code chunk number 40: seriation.Rnw:1664-1670
 ###################################################
 pdf(file = "seriation-dissplot1.pdf")
 ## plot original matrix
@@ -322,13 +320,13 @@ tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 41: seriation.Rnw:1672-1673
+### code chunk number 41: seriation.Rnw:1697-1698
 ###################################################
 set.seed(1234)
 
 
 ###################################################
-### code chunk number 42: seriation.Rnw:1675-1677
+### code chunk number 42: seriation.Rnw:1700-1702
 ###################################################
 l <- kmeans(d, 10)$cluster
 #$
@@ -342,7 +340,7 @@ l <- kmeans(d, 10)$cluster
 
 
 ###################################################
-### code chunk number 44: seriation.Rnw:1690-1703
+### code chunk number 44: seriation.Rnw:1715-1728
 ###################################################
 pdf(file = "seriation-dissplot3.pdf")
 
@@ -361,20 +359,20 @@ tmp <- dev.off()
 
 
 ###################################################
-### code chunk number 45: seriation.Rnw:1718-1719
+### code chunk number 45: seriation.Rnw:1743-1744
 ###################################################
 res
 
 
 ###################################################
-### code chunk number 46: seriation.Rnw:1738-1740 (eval = FALSE)
+### code chunk number 46: seriation.Rnw:1763-1765 (eval = FALSE)
 ###################################################
 ## plot(res, options = list(main = "Seriation - threshold",
 ##     threshold = 1.5))
 
 
 ###################################################
-### code chunk number 47: seriation.Rnw:1754-1757
+### code chunk number 47: seriation.Rnw:1779-1782
 ###################################################
 #names(res)
 table(iris[res$order, 5], res$label)[,res$cluster_order]
